// importing the libraries required for line graph
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  curveBasis
} from 'd3';

const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

//defining X-axis
const render = data => {
  const xValue = d => d.Year;
  // Label to be shown on x-axis
  const xAxisLabel = 'Year';
  
  //labeling band defining Y-axis
  const yValue = d => d.Subscribers;
  const circleRadius = 5;
  // Label to be shown on y-axis
  const yAxisLabel = 'number of subscribers';
  
  //styles of plot
  const margin = { top: 60, right: 40, bottom: 150, left: 105 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  // to create scales and axes 
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0,innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
   //block for creating a text element for a Y-axis
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(15);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -70)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  //block for creating a text element for a x-axis
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 50)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  //line graph genertor
  const lineGenerator = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue(d)))
 	  .curve(curveBasis);
  
  g.append('path')
      .attr('class', 'line-path')
      .attr('d', lineGenerator(data));
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};

//gist data is linked 
csv('https://gist.githubusercontent.com/Sheela2930/6def658d768dc1d67d90b1d10e41793b/raw/a76d7e799bd15ef671d56ebc716e67014855937a/Hulu_NumSubscribers.csv')
  .then(data => {
    data.forEach(d => {
      d.Subscribers = +d.Subscribers;
      d.Year = +d.Year;
    });
    render(data);
  });